# Smoke Testing

This assumes Python3.6 as a minimum.
This is because we currently test with FreeBSD 11.2, CentOS 7,
and Ubuntu 18.04, which now all use Python3.6+.

Since this is meant to run in a CI environment, logs are are removed on start up.
They are expected to be saved separately by the CI server when the scripts exit.

## Dependencies

```
python3 python3-requests python3-paramiko
```

See the container images for build dependencies if you want to compile without utilizing the containers.

## Running

An example layout of running this:

```
$HOME
├─<this directory>
└─workspace
  ├─dpdk.tar.gz
  │ # Below will be generated by the scripts
  ├─dpdk     # Extracted tarball to build
  ├─out      # The output directory, containing the logs
  └─out.zip  # The output directory, but zipped when the scripts exit
```

```bash
cd ~/workspace
../<this directory>/compile.py dpdk.tar.gz
```

The context is the current directory,
so the tarball will be extracted in the current directory,
and logs will be generated in the `out` directory.

## DPDK unit testing

Testing is attempted to run as a non-root user. In order to do this, there is some setup involved.

```bash
sudo groupadd hugetlbfs
sudo usermod -a -G hugetlbfs $USER # $USER is the user running the unit tests
sudo chown -R :hugetlbfs /dev/hugepages
sudo chmod g+w /dev/hugepages -R
sudo sh -c "echo 1024 > /proc/sys/vm/nr_hugepages"
```

## Running OVS Performance testing

This assumes the environment has already been set up. See:
https://github.com/chaudron/ovs_perf

## Some development thoughts/goals

Currently, the zip is the only artifact generated that is meant for public use.
Terminal output is mostly meant for debugging.
You must use the logger for the output to be saved to the artifact log.

Use `ci.run` to log commands and output. Otherwise, `subprocess` can be used.
If you want to see the command generated, but not log them,
use the `ci` variant of `subprocess` if it exists, like `ci.check_call`.
It should be used over `subprocess` anyways, since it allows options like `--print-shell`
to avoid actually running the commands.
That way, setup processes do not get logged, but it still gets printed to the terminal for debugging.
