#!/usr/bin/env python3
# SPDX-License-Identifier: BSD-3-Clause
# Copyright (c) 2019 DPDK Project. Developed by UNH-IOL dpdklab@iol.unh.edu.

import os
import shutil
from pathlib import Path

from ci_logging import OUTPUT_FOLDER
from compile import CompileArgParse, Compile


class CompileMesonArgParse(CompileArgParse):
    def __init__(self, description='Compile DPDK with meson'):
        super().__init__(description)


class CompileMeson(Compile):

    def save_logs(self):
        # save build logs (only needed on error)
        location = Path('dpdk/build')
        for name in ['meson-logs/testlog.txt', '.ninja_log',
                     'meson-logs/meson-log.txt']:
            full_name = location / name
            if os.path.exists(full_name):
                shutil.copy(full_name, OUTPUT_FOLDER)

    def build(self):
        self.init_dpdk()

        # For passing location of meson on windows
        # (for example: "C:\python\python.exe C:\meson\meson.py")
        meson = os.environ.get('MESON', 'meson').split(' ')
        extra_args = []
        # Not all examples compile on windows
        # There are also warnings on windows already (--werror)
        if self.execenv == 'windows':
            examples = 'helloworld'
        else:
            examples = 'all'
            extra_args += ['--default-library', 'shared', '--werror']

        # build dpdk
        self.run(meson + ['build', '-Dexamples=' + examples] + extra_args,
                 on_error=self.save_logs, cwd='dpdk')

        self.run(['ninja', '-C', 'build'],
                 on_error=self.save_logs, cwd='dpdk')

        # build docs
#        self.run(['ninja', '-C', 'build', 'doc'],
#                 on_error=self.save_logs, cwd='dpdk')


if __name__ == '__main__':
    args = CompileMesonArgParse().parse_args()

    compile_dpdk = CompileMeson(**vars(args))
    compile_dpdk.build()
