#!/usr/bin/env python3
# SPDX-License-Identifier: BSD-3-Clause
# Copyright (c) 2019 DPDK Project. Developed by UNH-IOL dpdklab@iol.unh.edu.

import os

from ci import ContainerMixin, OS
from compile_meson import CompileMeson, CompileMesonArgParse


class CompileWithPodmanArgParse(CompileMesonArgParse):
    def __init__(self, description='Compile DPDK with meson in a container'):
        super().__init__(description)
        self.parser.add_argument(
            '--os', choices=OS.CHOICES, default=OS.CHOICES[0],
            help='OS container to use')


class CompileMesonWithPodman(ContainerMixin, CompileMeson):

    def __init__(self, os, **kwargs):
        super().__init__(**kwargs)
        self.os = os

    def build(self):
        self.init_dpdk()

        image = 'dpdk_compile'

        self.image_build(image)

        self.container_run(image, [
            '-v', os.getcwd() + '/dpdk:/dpdk:Z',
            '--entrypoint', '/compile_meson.sh'],
                           on_error=self.save_logs)


if __name__ == '__main__':
    args = CompileWithPodmanArgParse().parse_args()

    compile_dpdk = CompileMesonWithPodman(**vars(args))
    compile_dpdk.build()
