#!/usr/bin/env python3
# SPDX-License-Identifier: BSD-3-Clause
# Copyright (c) 2019 DPDK Project. Developed by UNH-IOL dpdklab@iol.unh.edu.
import os
import shutil
import sys

from ci_logging import OUTPUT_FOLDER
from compile import Compile, CompileArgParse


class SPDKCompileArgParse(CompileArgParse):
    def __init__(self):
        super().__init__('SPDK Compile testing. This assumes an up-to-date '
                         'spdk git folder exists in the current directory.')


class SPDKMixin:
    def save_logs(self):
        # save logs (only needed on error)
        isal_log = 'spdk/isa-l/spdk-isal.log'
        if os.path.exists(isal_log):
            shutil.copy(isal_log, OUTPUT_FOLDER)

    def build_dpdk_and_check(self):
        if not os.path.exists('spdk'):
            print('The "spdk" folder does exist! Please make sure to clone '
                  'SPDK.')
            sys.exit(1)

        super().build()


class CompileSPDK(SPDKMixin, Compile):
    def build(self):
        self.build_dpdk_and_check()

        # run configure script
        self.run([
            './configure',
            '--with-dpdk=../dpdk/build',
            '--enable-werror',
            '--with-virtio',
            '--with-vhost',
        ], cwd='spdk', on_error=self.save_logs)

        self.run([self.make, 'clean'], cwd='spdk', on_error=self.save_logs)

        # compile spdk
        self.run([self.make, '-j' + self.cpu_count],
                 cwd='spdk',
                 on_error=self.save_logs)


if __name__ == '__main__':
    args = SPDKCompileArgParse().parse_args()

    compile_spdk = CompileSPDK(**vars(args))
    compile_spdk.build()
