#!/usr/bin/env python3
# SPDX-License-Identifier: BSD-3-Clause
# Copyright (c) 2019 DPDK Project. Developed by UNH-IOL dpdklab@iol.unh.edu.

import os

from compile_spdk import SPDKMixin
from compile_with_podman import CompileWithPodman, CompileWithPodmanArgParse


class SPDKCompileArgParse(CompileWithPodmanArgParse):
    def __init__(self):
        super().__init__('SPDK Compile testing. This assumes an up-to-date '
                         'spdk git folder exists in the current directory.')


class CompileSPDKWithPodman(SPDKMixin, CompileWithPodman):

    def build(self):
        self.build_dpdk_and_check()

        image = 'dpdk_compile'

        self.image_build(image)

        self.container_run(image, [
            '-v', os.getcwd() + '/dpdk:/dpdk:Z',
            '-v', os.getcwd() + '/spdk:/spdk:Z',
            '--entrypoint', '/compile_spdk.sh'],
                           on_error=self.save_logs)


if __name__ == '__main__':
    args = SPDKCompileArgParse().parse_args()

    compile_spdk = CompileSPDKWithPodman(**vars(args))
    compile_spdk.build()
