#!/usr/bin/env python3
# SPDX-License-Identifier: BSD-3-Clause
# Copyright (c) 2019 DPDK Project. Developed by UNH-IOL dpdklab@iol.unh.edu.

import os

from ci import ContainerMixin, OS
from compile import Compile, CompileArgParse


class CompileWithPodmanArgParse(CompileArgParse):
    def __init__(self, description='Compile dpdk in a container'):
        super().__init__(description)
        self.parser.add_argument(
            '--os', choices=OS.CHOICES, default=OS.CHOICES[0],
            help='OS container to use')


class CompileWithPodman(ContainerMixin, Compile):

    def __init__(self, os, **kwargs):
        super().__init__(**kwargs)
        self.os = os

    def build(self):
        if self.skip_build_dpdk and os.path.exists('dpdk'):
            return

        self.init_dpdk()

        self.apply_build_options()

        image = 'dpdk_compile'

        self.image_build(image)

        self.container_run(image, [
            '-e', f'RTE_KERNELDIR={self.kernels}/{self.kernel()}',
            '-v', os.getcwd() + '/dpdk:/dpdk:Z',
            '-v', f'{self.kernels}:{self.kernels}:ro',
            '--entrypoint', '/compile.sh'])


if __name__ == '__main__':
    args = CompileWithPodmanArgParse().parse_args()

    compile_dpdk = CompileWithPodman(**vars(args))
    compile_dpdk.build()
