FROM archlinux/base

RUN pacman -Sy --noconfirm \
    # Build aur packages
    cmake ninja pandoc python python-docutils ethtool file git fakeroot \
    # DPDK dependencies
    gcc make ninja pkg-config numactl elfutils gawk diffutils meson file \
    # Extra packages to compile as much as possible
    elfutils libmnl libpcap jansson ethtool

# Extra OVS packages
RUN pacman -Sy --noconfirm \
    python python-six openssl libcap-ng autoconf automake libtool

# add user for building aur packages
RUN useradd builder && \
    mkdir /home/builder && \
    chown builder:builder /home/builder

# switch user to make packages from aur
USER builder

# clone and make rdma-core packages
RUN cd /home/builder && git clone https://aur.archlinux.org/rdma-core.git
RUN gpg --recv-keys 921AFFAF83A9D7FD38CAA681E4637B88367258A7 42D25385C1A1C02B8B1B1C6F801BDDB825988F64
RUN cd /home/builder/rdma-core && makepkg

USER root

RUN cd /home/builder/rdma-core && pacman --noconfirm -U rdma-core-*.pkg.tar.xz

RUN rm -rf /home/builder

COPY compile.sh /compile.sh
COPY compile_meson.sh /compile_meson.sh
COPY compile_ovs.sh /compile_ovs.sh

ENV RTE_KERNELDIR CHANGE_ME
