#!/usr/bin/env python3
# SPDX-License-Identifier: BSD-3-Clause
# Copyright (c) 2019 DPDK Project. Developed by UNH-IOL dpdklab@iol.unh.edu.

import os
import sys

from compile import CompileArgParse
from compile_meson import CompileMeson


class RunUnitTestingArgParse(CompileArgParse):
    def __init__(self):
        super().__init__('Run DPDK unit testing')


class RunUnitTestingMixin:

    def can_use_hugetlbfs(self):
        # sanity check to make sure the user can write to /dev/hugepages
        # before trying to run the unit tests
        if not os.access('/dev/hugepages', os.W_OK):
            print('!!! Cannot write to /dev/hugepages. '
                  'See README for more information.')
            return False
        return True


class RunUnitTesting(RunUnitTestingMixin, CompileMeson):

    def run_unit_tests(self):
        if not self.can_use_hugetlbfs():
            return 1

        self.build()

        # run unit tests
        self.run(['meson', 'test', '-C', 'build',
                  '--suite', 'fast-tests', '-t', '3'],
                 on_error=self.save_logs, cwd='dpdk')


if __name__ == '__main__':
    args = RunUnitTestingArgParse().parse_args()

    unit_testing = RunUnitTesting(**vars(args))
    sys.exit(unit_testing.run_unit_tests())
