#!/usr/bin/env python3
# SPDX-License-Identifier: BSD-3-Clause
# Copyright (c) 2019 DPDK Project. Developed by UNH-IOL dpdklab@iol.unh.edu.

import os
import subprocess
import sys

from ci import OS
from compile_meson_with_docker import CompileMesonWithDocker
from unit_test import RunUnitTestingArgParse, RunUnitTestingMixin


class RunUnitTestingWithDockerArgParse(RunUnitTestingArgParse):
    def __init__(self):
        super().__init__()
        self.parser.add_argument(
            '--os', choices=OS.CHOICES, default=OS.CHOICES[0],
            help='OS container to use')


# TODO replace with podman
# Could not figure out how to run container user with
# group permissions (hugetlbfs)
# If this can run with podman, then CompileMesonWithDocker can be removed.
class RunUnitTestingWithDocker(RunUnitTestingMixin, CompileMesonWithDocker):

    def run_unit_tests(self):
        if not self.can_use_hugetlbfs():
            return 1

        self.build()

        image = 'dpdk_unit_test'

        self.image_build(image, manager='docker')

        hugetlbfs_gid = (subprocess.check_output(
            ['getent', 'group', 'hugetlbfs'])
            .decode('utf-8')
            .split(':')[2])

        self.container_run(image, [
            '--cap-add', 'IPC_LOCK',
            '--cap-add', 'NET_RAW',
            '--cap-add', 'NET_ADMIN',
            '--cap-add', 'SYS_NICE',
            '--user', f'{self.uid()}:{hugetlbfs_gid}',
            '-v', os.getcwd() + '/dpdk:/dpdk',
            '-v', '/dev/hugepages:/dev/hugepages'],
                           on_error=self.save_logs,
                           manager='docker')


if __name__ == '__main__':
    args = RunUnitTestingWithDockerArgParse().parse_args()

    unit_testing = RunUnitTestingWithDocker(**vars(args))
    sys.exit(unit_testing.run_unit_tests())
